@@ -1,5 +1,5 @@
 package Evo::Comp::Meta;
-use Evo 'Carp croak; -Lib::Internal monkey_patch; Module::Load load; -Lib::Bare';
+use Evo 'Carp croak; -Lib monkey_patch; Module::Load load; -Lib::Bare';
 
 
 our @CARP_NOT = qw(Evo::Comp::Gen::Array Evo::Comp::Gen::Hash Evo::Comp::Gen::HUF);
@@ -155,7 +155,7 @@ Evo::Comp::Meta
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 AUTHOR
 
