@@ -1,5 +1,5 @@
 package Evo::Loop::Role::Zone;
-use Evo '-Role *; -Lib::Internal *';
+use Evo '-Role *; -Lib *';
 use Carp 'croak';
 
 has zone_data => sub { {} };
@@ -42,7 +42,7 @@ Evo::Loop::Role::Zone
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 AUTHOR
 
