@@ -29,7 +29,7 @@ Evo::Net::Srv
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSYS
 
@@ -40,7 +40,7 @@ version 0.0201
 
   $srv->on(
     srv_accept => sub($srv, $sock) {
-      my ($ip, $port) = $sock->socket_remote;
+      my ($ip, $port) = $sock->io_remote;
       say sprintf("New connection from %s[%s], [%s]", $ip, $port, scalar localtime);
     }
   );
