@@ -1,12 +1,12 @@
 package Test::Evo::Helpers;
 use Evo '-Export *';
-use Evo '-Comp::Meta; Socket :all; -Role::Exporter; -Lib *; -Lib::Net *; Socket AF_INET6';
+use Evo '-Comp::Meta; Socket :all; -Role::Exporter; -Io *; -Lib::Net *; Socket AF_INET6';
 
 use constant CAN_BIND6 => eval {
   my ($saddr, $family) = net_gen_saddr_family('*', undef);
-  socket_open_nb()->socket_bind($saddr);
+  io_socket()->io_bind($saddr);
 };
-use constant HAS_REUSEPORT => eval { socket_open_nb()->socket_reuseport; 1; };
+use constant HAS_REUSEPORT => eval { io_socket()->io_reuseport; 1; };
 use constant HAS_SO_DOMAIN => eval { my $v = SO_DOMAIN(); 1 };
 
 export qw(CAN_BIND6 HAS_REUSEPORT HAS_SO_DOMAIN);
@@ -36,7 +36,7 @@ Test::Evo::Helpers
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 AUTHOR
 
